@@ -8,7 +8,7 @@ from pyinfra.connectors.util import remove_any_sudo_askpass_file
 
 from .connectors import get_execution_connector
 from .exceptions import ConnectError
-from .facts import create_host_fact, delete_host_fact, get_host_fact
+from .facts import create_host_fact, delete_host_fact, get_host_fact, reload_host_fact
 
 
 def extract_callable_datas(datas):
@@ -22,22 +22,22 @@ def extract_callable_datas(datas):
 
 
 class HostData(object):
-    '''
+    """
     Combines multiple AttrData's to search for attributes.
-    '''
+    """
 
     override_datas = None
 
     def __init__(self, host, *datas):
-        self.__dict__['host'] = host
+        self.__dict__["host"] = host
 
         datas = list(datas)
 
         # Inject an empty override data so we can assign during deploy
-        self.__dict__['override_datas'] = {}
+        self.__dict__["override_datas"] = {}
         datas.insert(0, self.override_datas)
 
-        self.__dict__['datas'] = tuple(datas)
+        self.__dict__["datas"] = tuple(datas)
 
     def __getattr__(self, key):
         for data in extract_callable_datas(self.datas):
@@ -46,7 +46,7 @@ class HostData(object):
             except KeyError:
                 pass
 
-        raise AttributeError(f'Host `{self.host}` has no data `{key}`')
+        raise AttributeError(f"Host `{self.host}` has no data `{key}`")
 
     def __setattr__(self, key, value):
         self.override_datas[key] = value
@@ -72,29 +72,35 @@ class HostData(object):
 
 
 class Host(object):
-    '''
+    """
     Represents a target host. Thin class that links up to facts and host/group
     data.
-    '''
+    """
 
     connection = None
     state = None
 
-    # Current context inside an @operation function
+    # Current context inside an @operation function (op gen stage)
     in_op = False
     current_op_hash = None
     current_op_global_kwargs = None
 
-    # Current context inside a @deploy function
+    # Current context inside a @deploy function (op gen stage)
     in_deploy = False
     current_deploy_name = None
     current_deploy_kwargs = None
     current_deploy_data = None
-    current_deploy_op_order = None
+
+    # Current context during operation execution
+    executing_op_hash = None
+    nested_executing_op_hash = None
 
     def __init__(
-        self, name, inventory, groups,
-        executor=get_execution_connector('ssh'),
+        self,
+        name,
+        inventory,
+        groups,
+        executor=get_execution_connector("ssh"),
     ):
         self.inventory = inventory
         self.groups = groups
@@ -108,6 +114,10 @@ class Host(object):
         self.facts = {}
         self.facts_lock = BoundedSemaphore()
 
+        # Append only list of operation hashes as called on this host, used to
+        # generate a DAG to create the final operation order.
+        self.op_hash_order = []
+
         # Create the (waterfall data: override, host, group, global)
         self.data = HostData(
             self,
@@ -120,10 +130,10 @@ class Host(object):
         )
 
     def __str__(self):
-        return '{0}'.format(self.name)
+        return "{0}".format(self.name)
 
     def __repr__(self):
-        return 'Host({0})'.format(self.name)
+        return "Host({0})".format(self.name)
 
     @property
     def connected(self):
@@ -139,14 +149,21 @@ class Host(object):
 
     @property
     def print_prefix(self):
-        return '{0}[{1}] '.format(
-            click.style(''),  # reset
+        if self.nested_executing_op_hash:
+            return "{0}[{1}] {2} ".format(
+                click.style(""),  # reset
+                click.style(self.name, bold=True),
+                click.style("nested", "blue"),
+            )
+
+        return "{0}[{1}] ".format(
+            click.style(""),  # reset
             click.style(self.name, bold=True),
         )
 
     def style_print_prefix(self, *args, **kwargs):
-        return '{0}[{1}] '.format(
-            click.style(''),  # reset
+        return "{0}[{1}] ".format(
+            click.style(""),  # reset
             click.style(self.name, *args, **kwargs),
         )
 
@@ -157,40 +174,42 @@ class Host(object):
         return {}
 
     def noop(self, description):
-        '''
+        """
         Log a description for a noop operation.
-        '''
+        """
 
         handler = logger.info if self.state.print_noop_info else logger.debug
-        handler('{0}noop: {1}'.format(self.print_prefix, description))
+        handler("{0}noop: {1}".format(self.print_prefix, description))
 
     @contextmanager
-    def deploy(self, name, kwargs, data, in_deploy=True, deploy_op_order=None):
-        '''
+    def deploy(self, name, kwargs, data, in_deploy=True):
+        """
         Wraps a group of operations as a deploy, this should not be used
         directly, instead use ``pyinfra.api.deploy.deploy``.
-        '''
+        """
 
         # Handle nested deploy names
         if self.current_deploy_name:
-            name = '{0} | {1}'.format(self.current_deploy_name, name)
+            name = "{0} | {1}".format(self.current_deploy_name, name)
 
         # Store the previous values
         old_in_deploy = self.in_deploy
         old_deploy_name = self.current_deploy_name
         old_deploy_kwargs = self.current_deploy_kwargs
         old_deploy_data = self.current_deploy_data
-        old_deploy_op_order = self.current_deploy_op_order
         self.in_deploy = in_deploy
 
         # Set the new values
         self.current_deploy_name = name
         self.current_deploy_kwargs = kwargs
         self.current_deploy_data = data
-        self.current_deploy_op_order = deploy_op_order
-        logger.debug('Starting deploy {0} (args={1}, data={2})'.format(
-            name, kwargs, data,
-        ))
+        logger.debug(
+            "Starting deploy {0} (args={1}, data={2})".format(
+                name,
+                kwargs,
+                data,
+            ),
+        )
 
         yield
 
@@ -199,11 +218,14 @@ class Host(object):
         self.current_deploy_name = old_deploy_name
         self.current_deploy_kwargs = old_deploy_kwargs
         self.current_deploy_data = old_deploy_data
-        self.current_deploy_op_order = old_deploy_op_order
 
-        logger.debug('Reset deploy to {0} (args={1}, data={2})'.format(
-            old_deploy_name, old_deploy_kwargs, old_deploy_data,
-        ))
+        logger.debug(
+            "Reset deploy to {0} (args={1}, data={2})".format(
+                old_deploy_name,
+                old_deploy_kwargs,
+                old_deploy_data,
+            ),
+        )
 
     # Host facts
     #
@@ -211,6 +233,9 @@ class Host(object):
     def get_fact(self, name_or_cls, *args, **kwargs):
         return get_host_fact(self.state, self, name_or_cls, args=args, kwargs=kwargs)
 
+    def reload_fact(self, name_or_cls, *args, **kwargs):
+        return reload_host_fact(self.state, self, name_or_cls, args=args, kwargs=kwargs)
+
     def create_fact(self, name_or_cls, data=None, kwargs=None):
         return create_host_fact(self.state, self, name_or_cls, data, kwargs=kwargs)
 
@@ -222,40 +247,40 @@ class Host(object):
 
     def _check_state(self):
         if not self.state:
-            raise TypeError('Cannot call this function with no state!')
+            raise TypeError("Cannot call this function with no state!")
 
     def connect(self, reason=None, show_errors=True, raise_exceptions=False):
         self._check_state()
         if not self.connection:
-            self.state.trigger_callbacks('host_before_connect', self)
+            self.state.trigger_callbacks("host_before_connect", self)
 
             try:
                 self.connection = self.executor.connect(self.state, self)
             except ConnectError as e:
                 if show_errors:
-                    log_message = '{0}{1}'.format(
+                    log_message = "{0}{1}".format(
                         self.print_prefix,
-                        click.style(e.args[0], 'red'),
+                        click.style(e.args[0], "red"),
                     )
                     logger.error(log_message)
 
-                self.state.trigger_callbacks('host_connect_error', self, e)
+                self.state.trigger_callbacks("host_connect_error", self, e)
 
                 if raise_exceptions:
                     raise
             else:
-                log_message = '{0}{1}'.format(
+                log_message = "{0}{1}".format(
                     self.print_prefix,
-                    click.style('Connected', 'green'),
+                    click.style("Connected", "green"),
                 )
                 if reason:
-                    log_message = '{0}{1}'.format(
+                    log_message = "{0}{1}".format(
                         log_message,
-                        ' ({0})'.format(reason),
+                        " ({0})".format(reason),
                     )
 
                 logger.info(log_message)
-                self.state.trigger_callbacks('host_connect', self)
+                self.state.trigger_callbacks("host_connect", self)
 
         return self.connection
 
@@ -263,14 +288,14 @@ class Host(object):
         self._check_state()
 
         # Disconnect is an optional function for executors if needed
-        disconnect_func = getattr(self.executor, 'disconnect', None)
+        disconnect_func = getattr(self.executor, "disconnect", None)
         if disconnect_func:
             return disconnect_func(self.state, self)
 
         # TODO: consider whether this should be here!
         remove_any_sudo_askpass_file(self)
 
-        self.state.trigger_callbacks('host_disconnect', self)
+        self.state.trigger_callbacks("host_disconnect", self)
 
     def run_shell_command(self, *args, **kwargs):
         self._check_state()
@@ -287,13 +312,15 @@ class Host(object):
     # Rsync - optional executor specific ability
 
     def check_can_rsync(self):
-        check_can_rsync_func = getattr(self.executor, 'check_can_rsync', None)
+        check_can_rsync_func = getattr(self.executor, "check_can_rsync", None)
         if check_can_rsync_func:
             return check_can_rsync_func(self)
 
-        raise NotImplementedError('The {0} connector does not support rsync!'.format(
-            self.executor.__name__,
-        ))
+        raise NotImplementedError(
+            "The {0} connector does not support rsync!".format(
+                self.executor.__name__,
+            ),
+        )
 
     def rsync(self, *args, **kwargs):
         self._check_state()
