@@ -180,6 +180,8 @@ class State(object):
         self.meta = {
             host: {
                 "ops": 0,  # one function call in a deploy file
+                "ops_change": 0,
+                "ops_no_change": 0,
                 "commands": 0,  # actual # of commands to run
                 "op_hashes": set(),
             }
@@ -192,6 +194,8 @@ class State(object):
                 "ops": 0,  # success_ops + failed ops w/ignore_errors
                 "success_ops": 0,
                 "error_ops": 0,
+                "ignored_error_ops": 0,
+                "partial_ops": 0,  # operations that had an error, but did do something
                 "commands": 0,
             }
             for host in inventory
