@@ -2,11 +2,11 @@ from pyinfra.api import FactBase
 
 from .util.packaging import parse_packages
 
-APK_REGEX = r'^([a-zA-Z\-]+)-([0-9\.]+\-?[a-z0-9]*)\s'
+APK_REGEX = r"^([a-zA-Z\-]+)-([0-9\.]+\-?[a-z0-9]*)\s"
 
 
 class ApkPackages(FactBase):
-    '''
+    """
     Returns a dict of installed apk packages:
 
     .. code:: python
@@ -14,10 +14,10 @@ class ApkPackages(FactBase):
         {
             "package_name": ["version"],
         }
-    '''
+    """
 
-    command = 'apk list --installed'
-    requires_command = 'apk'
+    command = "apk list --installed"
+    requires_command = "apk"
 
     default = dict
 
