@@ -2,11 +2,11 @@ from pyinfra.api import FactBase
 
 from .util.packaging import parse_packages
 
-GEM_REGEX = r'^([a-zA-Z0-9\-\+\_]+)\s\(([0-9\.]+)\)$'
+GEM_REGEX = r"^([a-zA-Z0-9\-\+\_]+)\s\(([0-9\.]+)\)$"
 
 
 class GemPackages(FactBase):
-    '''
+    """
     Returns a dict of installed gem packages:
 
     .. code:: python
@@ -14,10 +14,10 @@ class GemPackages(FactBase):
         {
             'package_name': ['version'],
         }
-    '''
+    """
 
-    command = 'gem list --local'
-    requires_command = 'gem'
+    command = "gem list --local"
+    requires_command = "gem"
 
     default = dict
 
