@@ -4,11 +4,11 @@ from pyinfra.api import FactBase, ShortFactBase
 
 
 class Cpus(FactBase):
-    '''
+    """
     Returns the number of CPUs on this server.
-    '''
+    """
 
-    command = 'getconf NPROCESSORS_ONLN 2> /dev/null || getconf _NPROCESSORS_ONLN'
+    command = "getconf NPROCESSORS_ONLN 2> /dev/null || getconf _NPROCESSORS_ONLN"
 
     @staticmethod
     def process(output):
@@ -19,12 +19,12 @@ class Cpus(FactBase):
 
 
 class Memory(FactBase):
-    '''
+    """
     Returns the memory installed in this server, in MB.
-    '''
+    """
 
-    command = 'vmstat -s'
-    requires_command = 'vmstat'
+    command = "vmstat -s"
+    requires_command = "vmstat"
 
     @staticmethod
     def process(output):
@@ -32,7 +32,7 @@ class Memory(FactBase):
 
         for line in output:
             line = line.strip()
-            value, key = line.split(' ', 1)
+            value, key = line.split(" ", 1)
 
             try:
                 value = int(value)
@@ -42,12 +42,12 @@ class Memory(FactBase):
             data[key.strip()] = value
 
         # Easy - Linux just gives us the number
-        total_memory = data.get('K total memory', data.get('total memory'))
+        total_memory = data.get("K total memory", data.get("total memory"))
 
         # BSD - calculate the total from the # pages and the page size
         if not total_memory:
-            bytes_per_page = data.get('bytes per page')
-            pages_managed = data.get('pages managed')
+            bytes_per_page = data.get("bytes per page")
+            pages_managed = data.get("pages managed")
 
             if bytes_per_page and pages_managed:
                 total_memory = (pages_managed * bytes_per_page) / 1024
@@ -57,7 +57,7 @@ class Memory(FactBase):
 
 
 class BlockDevices(FactBase):
-    '''
+    """
     Returns a dict of (mounted) block devices:
 
     .. code:: python
@@ -71,10 +71,10 @@ class BlockDevices(FactBase):
                 "blocks": "40325900"
             },
         }
-    '''
+    """
 
-    command = 'df'
-    regex = r'([a-zA-Z0-9\/\-_]+)\s+([0-9]+)\s+([0-9]+)\s+([0-9]+)\s+([0-9]{1,3})%\s+([a-zA-Z\/0-9\-_]+)'  # noqa: E501
+    command = "df"
+    regex = r"([a-zA-Z0-9\/\-_]+)\s+([0-9]+)\s+([0-9]+)\s+([0-9]+)\s+([0-9]{1,3})%\s+([a-zA-Z\/0-9\-_]+)"  # noqa: E501
     default = dict
 
     def process(self, output):
@@ -83,15 +83,15 @@ class BlockDevices(FactBase):
         for line in output:
             matches = re.match(self.regex, line)
             if matches:
-                if matches.group(1) == 'none':
+                if matches.group(1) == "none":
                     continue
 
                 devices[matches.group(1)] = {
-                    'blocks': matches.group(2),
-                    'used': matches.group(3),
-                    'available': matches.group(4),
-                    'used_percent': matches.group(5),
-                    'mount': matches.group(6),
+                    "blocks": matches.group(2),
+                    "used": matches.group(3),
+                    "available": matches.group(4),
+                    "used_percent": matches.group(5),
+                    "mount": matches.group(6),
                 }
 
         return devices
@@ -99,42 +99,42 @@ class BlockDevices(FactBase):
 
 nettools_1_regexes = [
     (
-        r'^inet addr:([0-9\.]+).+Bcast:([0-9\.]+).+Mask:([0-9\.]+)$',
-        ('ipv4', 'address', 'broadcast', 'netmask'),
+        r"^inet addr:([0-9\.]+).+Bcast:([0-9\.]+).+Mask:([0-9\.]+)$",
+        ("ipv4", "address", "broadcast", "netmask"),
     ),
     (
-        r'^inet6 addr: ([0-9a-z:]+)\/([0-9]+) Scope:Global',
-        ('ipv6', 'address', 'mask_bits'),
+        r"^inet6 addr: ([0-9a-z:]+)\/([0-9]+) Scope:Global",
+        ("ipv6", "address", "mask_bits"),
     ),
 ]
 
 nettools_2_regexes = [
     (
-        r'^inet ([0-9\.]+)\s+netmask ([0-9\.fx]+)(?:\s+broadcast ([0-9\.]+))?$',
-        ('ipv4', 'address', 'netmask', 'broadcast'),
+        r"^inet ([0-9\.]+)\s+netmask ([0-9\.fx]+)(?:\s+broadcast ([0-9\.]+))?$",
+        ("ipv4", "address", "netmask", "broadcast"),
     ),
     (
-        r'^inet6 ([0-9a-z:]+)\s+prefixlen ([0-9]+)',
-        ('ipv6', 'address', 'mask_bits'),
+        r"^inet6 ([0-9a-z:]+)\s+prefixlen ([0-9]+)",
+        ("ipv6", "address", "mask_bits"),
     ),
 ]
 
 iproute2_regexes = [
     (
-        r'^inet ([0-9\.]+)\/([0-9]{1,2})(?:\s+brd ([0-9\.]+))?',
-        ('ipv4', 'address', 'mask_bits', 'broadcast'),
+        r"^inet ([0-9\.]+)\/([0-9]{1,2})(?:\s+brd ([0-9\.]+))?",
+        ("ipv4", "address", "mask_bits", "broadcast"),
     ),
     (
-        r'^inet6 ([0-9a-z:]+)\/([0-9]{1,3})',
-        ('ipv6', 'address', 'mask_bits'),
+        r"^inet6 ([0-9a-z:]+)\/([0-9]{1,3})",
+        ("ipv6", "address", "mask_bits"),
     ),
 ]
 
 
 def _parse_regexes(regexes, lines):
     data = {
-        'ipv4': {},
-        'ipv6': {},
+        "ipv4": {},
+        "ipv6": {},
     }
 
     for line in lines:
@@ -146,12 +146,12 @@ def _parse_regexes(regexes, lines):
                 for i, group in enumerate(groups[1:]):
                     ip_data[group] = matches.group(i + 1)
 
-                if 'mask_bits' in ip_data:
-                    ip_data['mask_bits'] = int(ip_data['mask_bits'])
+                if "mask_bits" in ip_data:
+                    ip_data["mask_bits"] = int(ip_data["mask_bits"])
 
                 target_group = data[groups[0]]
-                if target_group.get('address'):
-                    target_group.setdefault('additional_ips', []).append(ip_data)
+                if target_group.get("address"):
+                    target_group.setdefault("additional_ips", []).append(ip_data)
                 else:
                     target_group.update(ip_data)
 
@@ -161,7 +161,7 @@ def _parse_regexes(regexes, lines):
 
 
 class NetworkDevices(FactBase):
-    '''
+    """
     Gets & returns a dict of network devices. See the ``ipv4_addresses`` and
     ``ipv6_addresses`` facts for easier-to-use shortcuts to get device addresses.
 
@@ -186,24 +186,24 @@ class NetworkDevices(FactBase):
                 }
             },
         }
-    '''
+    """
 
-    command = 'ip addr show 2> /dev/null || ifconfig'
+    command = "ip addr show 2> /dev/null || ifconfig"
     default = dict
 
     # Definition of valid interface names for Linux:
     # https://git.kernel.org/pub/scm/linux/kernel/git/stable/linux.git/tree/net/core/dev.c?h=v5.1.3#n1020
     _start_regexes = [
         (
-            r'^([^/: \s]+)\s+Link encap:',
+            r"^([^/: \s]+)\s+Link encap:",
             lambda lines: _parse_regexes(nettools_1_regexes, lines),
         ),
         (
-            r'^([^/: \s]+): flags=',
+            r"^([^/: \s]+): flags=",
             lambda lines: _parse_regexes(nettools_2_regexes, lines),
         ),
         (
-            r'^[0-9]+: ([^/: \s]+): ',
+            r"^[0-9]+: ([^/: \s]+): ",
             lambda lines: _parse_regexes(iproute2_regexes, lines),
         ),
     ]
@@ -250,7 +250,7 @@ class NetworkDevices(FactBase):
 
 
 class Ipv4Addrs(ShortFactBase):
-    '''
+    """
     Gets & returns a dictionary of network interface -> list of IPv4 addresses.
 
     .. code:: python
@@ -261,10 +261,10 @@ class Ipv4Addrs(ShortFactBase):
 
     .. note::
         Network interfaces with no IPv4 will not be part of the dictionary.
-    '''
+    """
 
     fact = NetworkDevices
-    ip_type = 'ipv4'
+    ip_type = "ipv4"
 
     def process_data(self, data):
         host_to_ips = {}
@@ -276,9 +276,9 @@ class Ipv4Addrs(ShortFactBase):
             if not ip_details:
                 continue
 
-            ips.append(ip_details['address'])
-            if 'additional_ips' in ip_details:
-                ips.extend([ip['address'] for ip in ip_details['additional_ips']])
+            ips.append(ip_details["address"])
+            if "additional_ips" in ip_details:
+                ips.extend([ip["address"] for ip in ip_details["additional_ips"]])
 
             host_to_ips[interface] = ips
 
@@ -286,7 +286,7 @@ class Ipv4Addrs(ShortFactBase):
 
 
 class Ipv6Addrs(Ipv4Addrs):
-    '''
+    """
     Gets & returns a dictionary of network interface -> list of IPv6 addresses.
 
     .. code:: python
@@ -297,17 +297,18 @@ class Ipv6Addrs(Ipv4Addrs):
 
     .. note::
         Network interfaces with no IPv6 will not be part of the dictionary.
-    '''
+    """
 
-    ip_type = 'ipv6'
+    ip_type = "ipv6"
 
 
 # TODO: remove these in v3
 # Legacy versions of the above that only support one IP per interface
 #
 
+
 class Ipv4Addresses(ShortFactBase):
-    '''
+    """
     Gets & returns a dictionary of network interface -> IPv4 address.
 
     .. code:: python
@@ -321,10 +322,10 @@ class Ipv4Addresses(ShortFactBase):
 
     .. note::
         Network interfaces with no IPv4 will not be part of the dictionary.
-    '''
+    """
 
     fact = NetworkDevices
-    ip_type = 'ipv4'
+    ip_type = "ipv4"
 
     def process_data(self, data):
         addresses = {}
@@ -334,13 +335,13 @@ class Ipv4Addresses(ShortFactBase):
             if not ip_details:
                 continue  # pramga: no cover
 
-            addresses[interface] = ip_details['address']
+            addresses[interface] = ip_details["address"]
 
         return addresses
 
 
 class Ipv6Addresses(Ipv4Addresses):
-    '''
+    """
     Gets & returns a dictionary of network interface -> IPv6 address.
 
     .. code:: python
@@ -354,6 +355,6 @@ class Ipv6Addresses(Ipv4Addresses):
 
     .. note::
         Network interfaces with no IPv6 will not be part of the dictionary.
-    '''
+    """
 
-    ip_type = 'ipv6'
+    ip_type = "ipv6"
