@@ -4,12 +4,12 @@ from pyinfra.api import FactBase
 
 
 class LxdContainers(FactBase):
-    '''
+    """
     Returns a list of running LXD containers
-    '''
+    """
 
-    command = 'lxc list --format json --fast'
-    requires_command = 'lxc'
+    command = "lxc list --format json --fast"
+    requires_command = "lxc"
 
     default = list
 
