@@ -2,11 +2,11 @@ from pyinfra.api import FactBase
 
 from .util.packaging import parse_packages
 
-PKGIN_REGEX = r'^([a-zA-Z\-0-9]+)-([0-9\.]+\-?[a-z0-9]*)\s'
+PKGIN_REGEX = r"^([a-zA-Z\-0-9]+)-([0-9\.]+\-?[a-z0-9]*)\s"
 
 
 class PkginPackages(FactBase):
-    '''
+    """
     Returns a dict of installed pkgin packages:
 
     .. code:: python
@@ -14,10 +14,10 @@ class PkginPackages(FactBase):
         {
             "package_name": ["version"],
         }
-    '''
+    """
 
-    command = 'pkgin list'
-    requires_command = 'pkgin'
+    command = "pkgin list"
+    requires_command = "pkgin"
 
     default = dict
 
