@@ -2,7 +2,6 @@ import re
 
 from pyinfra.api import FactBase
 
-
 # Valid unit names consist of a "name prefix" and a dot and a suffix specifying the unit type.
 # The "unit prefix" must consist of one or more valid characters
 # (ASCII letters, digits, ":", "-", "_", ".", and "\").
@@ -15,29 +14,29 @@ from pyinfra.api import FactBase
 # The name of the full unit is formed by inserting the instance name
 # between "@" and the unit type suffix.
 SYSTEMD_UNIT_NAME_REGEX = (
-    r'[a-zA-Z0-9\:\-\_\.\\\@]+\.'
-    r'(?:service|socket|device|mount|automount|swap|target|path|timer|slice|scope)'
+    r"[a-zA-Z0-9\:\-\_\.\\\@]+\."
+    r"(?:service|socket|device|mount|automount|swap|target|path|timer|slice|scope)"
 )
 
 
 def _make_systemctl_cmd(user_mode=False, machine=None, user_name=None):
     # base command for normal and user mode
-    systemctl_cmd = 'systemctl --user' if user_mode else 'systemctl'
+    systemctl_cmd = "systemctl --user" if user_mode else "systemctl"
 
     # add user and machine flag if given in args
     if machine is not None:
         if user_name is not None:
-            machine_opt = '--machine={1}@{0}'.format(machine, user_name)
+            machine_opt = "--machine={1}@{0}".format(machine, user_name)
         else:
-            machine_opt = '--machine={0}'.format(machine)
+            machine_opt = "--machine={0}".format(machine)
 
-        systemctl_cmd = '{0} {1}'.format(systemctl_cmd, machine_opt)
+        systemctl_cmd = "{0} {1}".format(systemctl_cmd, machine_opt)
 
     return systemctl_cmd
 
 
 class SystemdStatus(FactBase):
-    '''
+    """
     Returns a dictionary map of systemd units to booleans indicating whether they are active.
 
     + user_mode: whether to use user mode
@@ -50,14 +49,14 @@ class SystemdStatus(FactBase):
             "containerd.service": True,
             "apt-daily.timer": False,
         }
-    '''
+    """
 
-    requires_command = 'systemctl'
+    requires_command = "systemctl"
 
     default = dict
 
-    state_key = 'SubState'
-    state_values = ('running', 'waiting', 'exited')
+    state_key = "SubState"
+    state_values = ("running", "waiting", "exited")
 
     def command(self, user_mode=False, machine=None, user_name=None):
         fact_cmd = _make_systemctl_cmd(
@@ -76,12 +75,12 @@ class SystemdStatus(FactBase):
             line = line.strip()
 
             try:
-                key, value = line.split('=', 1)
+                key, value = line.split("=", 1)
             except ValueError:
                 current_unit = None  # reset current_unit just in case
                 continue
 
-            if key == 'Id' and re.match(SYSTEMD_UNIT_NAME_REGEX, value):
+            if key == "Id" and re.match(SYSTEMD_UNIT_NAME_REGEX, value):
                 current_unit = value
                 continue
 
@@ -92,7 +91,7 @@ class SystemdStatus(FactBase):
 
 
 class SystemdEnabled(SystemdStatus):
-    '''
+    """
     Returns a dictionary map of systemd units to booleans indicating whether they are enabled.
 
     .. code:: python
@@ -102,7 +101,7 @@ class SystemdEnabled(SystemdStatus):
             "containerd.service": True,
             "apt-daily.timer": False,
         }
-    '''
+    """
 
-    state_key = 'UnitFileState'
-    state_values = ('enabled', 'static')
+    state_key = "UnitFileState"
+    state_values = ("enabled", "static")
