@@ -45,7 +45,8 @@ from pyinfra.facts.files import (
 )
 from pyinfra.facts.server import Date, Which
 
-from .util.files import chmod, chown, ensure_mode_int, get_timestamp, sed_replace, unix_path_join
+from .util import files as file_utils
+from .util.files import ensure_mode_int, get_timestamp, sed_replace, unix_path_join
 
 
 @operation(
@@ -62,6 +63,8 @@ def download(
     sha256sum=None,
     sha1sum=None,
     md5sum=None,
+    headers=None,
+    insecure=False,
 ):
     """
     Download files from remote locations using ``curl`` or ``wget``.
@@ -76,6 +79,8 @@ def download(
     + sha256sum: sha256 hash to checksum the downloaded file against
     + sha1sum: sha1 hash to checksum the downloaded file against
     + md5sum: md5 hash to checksum the downloaded file against
+    + headers: optional dictionary of headers to set for the HTTP request
+    + insecure: disable SSL verification for the HTTP request
 
     **Example:**
 
@@ -130,13 +135,27 @@ def download(
     if download:
         temp_file = state.get_temp_filename(dest)
 
+        curl_args = ["-sSLf"]
+        wget_args = ["-q"]
+        if insecure:
+            curl_args.append("--insecure")
+            wget_args.append("--no-check-certificate")
+
+        if headers:
+            for key, value in headers.items():
+                header_arg = StringCommand("--header", QuoteString(f"{key}: {value}"))
+                curl_args.append(header_arg)
+                wget_args.append(header_arg)
+
         curl_command = make_formatted_string_command(
-            "curl -sSLf {0} -o {1}",
+            "curl {0} {1} -o {2}",
+            StringCommand(*curl_args),
             QuoteString(src),
             QuoteString(temp_file),
         )
         wget_command = make_formatted_string_command(
-            "wget -q {0} -O {1} || ( rm -f {1} ; exit 1 )",
+            "wget {0} {1} -O {2} || ( rm -f {2} ; exit 1 )",
+            StringCommand(*wget_args),
             QuoteString(src),
             QuoteString(temp_file),
         )
@@ -151,10 +170,10 @@ def download(
         yield StringCommand("mv", QuoteString(temp_file), QuoteString(dest))
 
         if user or group:
-            yield chown(dest, user, group)
+            yield file_utils.chown(dest, user, group)
 
         if mode:
-            yield chmod(dest, mode)
+            yield file_utils.chmod(dest, mode)
 
         if sha1sum:
             yield make_formatted_string_command(
@@ -536,6 +555,7 @@ def sync(
     user=None,
     group=None,
     mode=None,
+    dir_mode=None,
     delete=False,
     exclude=None,
     exclude_dir=None,
@@ -550,6 +570,7 @@ def sync(
     + user: user to own the files and directories
     + group: group to own the files and directories
     + mode: permissions of the files
+    + dir_mode: permissions of the directories
     + delete: delete remote files not present locally
     + exclude: string or list/tuple of strings to match & exclude files (eg *.pyc)
     + exclude_dir: string or list/tuple of strings to match & exclude directories (eg node_modules)
@@ -637,16 +658,16 @@ def sync(
         dest_to_ensure,
         user=user,
         group=group,
-        mode=get_path_permissions_mode(src),
+        mode=dir_mode or get_path_permissions_mode(src),
     )
 
     # Ensure any remote dirnames
-    for dirpath, dir_mode in ensure_dirnames:
+    for dir_path_curr, dir_mode_curr in ensure_dirnames:
         yield from directory(
-            unix_path_join(dest, dirpath),
+            unix_path_join(dest, dir_path_curr),
             user=user,
             group=group,
-            mode=dir_mode,
+            mode=dir_mode or dir_mode_curr,
         )
 
     # Put each file combination
@@ -809,7 +830,7 @@ def put(
     + dest: remote filename to upload to
     + user: user to own the files
     + group: group to own the files
-    + mode: permissions of the files
+    + mode: permissions of the files, use ``True`` to copy the local file
     + add_deploy_dir: src is relative to the deploy directory
     + create_remote_dir: create the remote directory if it doesn't exist
     + force: always upload the file, even if the remote copy matches
@@ -819,6 +840,10 @@ def put(
         If this is a directory that already exists on the remote side, the local
         file will be uploaded to that directory with the same filename.
 
+    ``mode``:
+        When set to ``True`` the permissions of the local file are applied to the
+        remote file after the upload is complete.
+
     ``create_remote_dir``:
         If the remote directory does not exist it will be created using the same
         user & group as passed to ``files.put``. The mode will *not* be copied over,
@@ -849,6 +874,7 @@ def put(
     # Upload IO objects as-is
     if hasattr(src, "read"):
         local_file = src
+        local_sum = get_file_sha1(src)
 
     # Assume string filename
     else:
@@ -858,23 +884,34 @@ def put(
 
         local_file = src
 
-        if not assume_exists and not os.path.isfile(local_file):
+        if os.path.isfile(local_file):
+            local_sum = get_file_sha1(local_file)
+        elif assume_exists:
+            local_sum = None
+        else:
             raise IOError("No such file: {0}".format(local_file))
 
-    mode = ensure_mode_int(mode)
+    if mode is True:
+        if os.path.isfile(local_file):
+            mode = get_path_permissions_mode(local_file)
+        else:
+            logger.warning(
+                ("No local file exists to get permissions from with `mode=True` ({0})").format(
+                    get_call_location(),
+                ),
+            )
+    else:
+        mode = ensure_mode_int(mode)
+
     remote_file = host.get_fact(File, path=dest)
 
     if not remote_file and host.get_fact(Directory, path=dest):
         dest = unix_path_join(dest, os.path.basename(src))
+        remote_file = host.get_fact(File, path=dest)
 
     if create_remote_dir:
         yield from _create_remote_dir(state, host, dest, user, group)
 
-    if assume_exists and not os.path.isfile(local_file):
-        local_sum = None
-    else:
-        local_sum = get_file_sha1(src)
-
     # No remote file, always upload and user/group/mode if supplied
     if not remote_file or force:
         yield FileUploadCommand(
@@ -884,10 +921,10 @@ def put(
         )
 
         if user or group:
-            yield chown(dest, user, group)
+            yield file_utils.chown(dest, user, group)
 
         if mode:
-            yield chmod(dest, mode)
+            yield file_utils.chmod(dest, mode)
 
     # File exists, check sum and check user/group/mode if supplied
     else:
@@ -902,22 +939,22 @@ def put(
             )
 
             if user or group:
-                yield chown(dest, user, group)
+                yield file_utils.chown(dest, user, group)
 
             if mode:
-                yield chmod(dest, mode)
+                yield file_utils.chmod(dest, mode)
 
         else:
             changed = False
 
             # Check mode
             if mode and remote_file["mode"] != mode:
-                yield chmod(dest, mode)
+                yield file_utils.chmod(dest, mode)
                 changed = True
 
             # Check user/group
             if (user and remote_file["user"] != user) or (group and remote_file["group"] != group):
-                yield chown(dest, user, group)
+                yield file_utils.chown(dest, user, group)
                 changed = True
 
             if not changed:
@@ -1183,7 +1220,7 @@ def link(
         yield add_cmd
 
         if user or group:
-            yield chown(path, user, group, dereference=False)
+            yield file_utils.chown(path, user, group, dereference=False)
 
         host.create_fact(
             Link,
@@ -1230,7 +1267,7 @@ def link(
             or (user and info["user"] != user)
             or (group and info["group"] != group)
         ):
-            yield chown(path, user, group, dereference=False)
+            yield file_utils.chown(path, user, group, dereference=False)
             changed = True
             if user:
                 info["user"] = user
@@ -1317,9 +1354,9 @@ def file(
         yield StringCommand("touch", QuoteString(path))
 
         if mode:
-            yield chmod(path, mode)
+            yield file_utils.chmod(path, mode)
         if user or group:
-            yield chown(path, user, group)
+            yield file_utils.chown(path, user, group)
 
         host.create_fact(
             File,
@@ -1346,7 +1383,7 @@ def file(
 
         # Check mode
         if mode and (not info or info["mode"] != mode):
-            yield chmod(path, mode)
+            yield file_utils.chmod(path, mode)
             info["mode"] = mode
             changed = True
 
@@ -1356,7 +1393,7 @@ def file(
             or (user and info["user"] != user)
             or (group and info["group"] != group)
         ):
-            yield chown(path, user, group)
+            yield file_utils.chown(path, user, group)
             changed = True
             if user:
                 info["user"] = user
@@ -1446,9 +1483,9 @@ def directory(
     if not assume_present and info is None and present:
         yield StringCommand("mkdir", "-p", QuoteString(path))
         if mode:
-            yield chmod(path, mode, recursive=recursive)
+            yield file_utils.chmod(path, mode, recursive=recursive)
         if user or group:
-            yield chown(path, user, group, recursive=recursive)
+            yield file_utils.chown(path, user, group, recursive=recursive)
 
         host.create_fact(
             Directory,
@@ -1473,7 +1510,7 @@ def directory(
         changed = False
 
         if mode and (not info or info["mode"] != mode):
-            yield chmod(path, mode, recursive=recursive)
+            yield file_utils.chmod(path, mode, recursive=recursive)
             info["mode"] = mode
             changed = True
 
@@ -1482,7 +1519,7 @@ def directory(
             or (user and info["user"] != user)
             or (group and info["group"] != group)
         ):
-            yield chown(path, user, group, recursive=recursive)
+            yield file_utils.chown(path, user, group, recursive=recursive)
             changed = True
             if user:
                 info["user"] = user
