@@ -336,7 +336,7 @@ def hostname(hostname, hostname_file=None):
         The hostname file only matters no systems that do not have ``hostnamectl``,
         which is part of ``systemd``.
 
-        By default pyinfra will auto detect this by targetting ``/etc/hostname``
+        By default pyinfra will auto detect this by targeting ``/etc/hostname``
         on Linux and ``/etc/myname`` on OpenBSD.
 
         To completely disable writing the hostname file, set ``hostname_file=False``.
@@ -801,6 +801,101 @@ def group(group, present=True, system=False, gid=None):
         groups.append(group)
 
 
+@operation
+def user_authorized_keys(
+    user,
+    public_keys,
+    group=None,
+    delete_keys=False,
+    authorized_key_directory=None,
+    authorized_key_filename=None,
+):
+    """
+    Manage `authorized_keys` of system users.
+
+    + user: name of the user to ensure
+    + public_keys: list of public keys to attach to this user, ``home`` must be specified
+    + group: the users primary group
+    + delete_keys: whether to remove any keys not specified in ``public_keys``
+
+    Public keys:
+        These can be provided as strings containing the public key or as a path to
+        a public key file which ``pyinfra`` will read.
+
+    **Examples:**
+
+    .. code:: python
+
+        server.user_authorized_keys(
+            name="Ensure user has a public key",
+            user="kevin",
+            public_keys=["ed25519..."],
+        )
+    """
+    if not authorized_key_directory:
+        authorized_key_directory = f"/home/{user}/.ssh/"
+    if not authorized_key_filename:
+        authorized_key_filename = "authorized_keys"
+
+    if isinstance(public_keys, str):
+        public_keys = [public_keys]
+
+    def read_any_pub_key_file(key):
+        try_path = key
+        if state.cwd:
+            try_path = path.join(state.cwd, key)
+
+        if path.exists(try_path):
+            with open(try_path, "r") as f:
+                return f.read()
+
+        return key
+
+    public_keys = list(map(read_any_pub_key_file, public_keys))
+
+    # Ensure .ssh directory
+    # note that this always outputs commands unless the SSH user has access to the
+    # authorized_keys file, ie the SSH user is the user defined in this function
+    yield from files.directory(
+        authorized_key_directory,
+        user=user,
+        group=group or user,
+        mode=700,
+    )
+
+    authorized_key_file = f"{authorized_key_directory}/{authorized_key_filename}"
+
+    if delete_keys:
+        # Create a whole new authorized_keys file
+        keys_file = StringIO(
+            "{0}\n".format(
+                "\n".join(public_keys),
+            ),
+        )
+
+        # And ensure it exists
+        yield from files.put(
+            src=keys_file,
+            dest=authorized_key_file,
+            user=user,
+            group=group or user,
+            mode=600,
+        )
+
+    else:
+        # Ensure authorized_keys exists
+        yield from files.file(
+            path=authorized_key_file,
+            user=user,
+            group=group or user,
+            mode=600,
+        )
+
+        # And every public key is present
+        for key in public_keys:
+            yield from files.line(path=authorized_key_file, line=key)
+
+
 @operation
 def user(
     user,
@@ -812,6 +907,7 @@ def user(
     public_keys=None,
     delete_keys=False,
     ensure_home=True,
+    create_home=False,
     system=False,
     uid=None,
     comment=None,
@@ -830,6 +926,7 @@ def user(
     + public_keys: list of public keys to attach to this user, ``home`` must be specified
     + delete_keys: whether to remove any keys not specified in ``public_keys``
     + ensure_home: whether to ensure the ``home`` directory exists
+    + create_home: whether to new user create home directories from the system skeleton
     + system: whether to create a system account
     + comment: the user GECOS comment
     + add_deploy_dir: any public_key filenames are relative to the deploy directory
@@ -837,7 +934,9 @@ def user(
 
     Home directory:
         When ``ensure_home`` or ``public_keys`` are provided, ``home`` defaults to
-        ``/home/{name}``.
+        ``/home/{name}``. When ``create_home`` is ``True`` any newly created users
+        will be created with the ``-m`` flag to build a new home directory from the
+        systems skeleton directory.
 
     Public keys:
         These can be provided as strings containing the public key or as a path to
@@ -869,6 +968,7 @@ def user(
     """
 
     users = host.get_fact(Users)
+    existing_groups = host.get_fact(Groups)
     existing_user = users.get(user)
 
     if groups is None:
@@ -888,6 +988,11 @@ def user(
 
     # User doesn't exist but we want them?
     if present and existing_user is None:
+        # Fix the case where a group of the same name already exists, tell useradd to use this
+        # group rather than failing trying to create it.
+        if not group and user in existing_groups:
+            group = user
+
         # Create the user w/home/shell
         args = []
 
@@ -915,6 +1020,9 @@ def user(
         if not unique:
             args.append("-o")
 
+        if create_home:
+            args.append("-m")
+
         # Users are often added by other operations (package installs), so check
         # for the user at runtime before adding.
         yield "grep '^{1}:' /etc/passwd || useradd {0} {1}".format(
@@ -972,64 +1080,17 @@ def user(
             home,
             user=user,
             group=group or user,
+            # Don't fail if the home directory exists as a link
+            _no_fail_on_link=True,
         )
 
     # Add SSH keys
     if public_keys is not None:
-        if isinstance(public_keys, str):
-            public_keys = [public_keys]
-
-        def read_any_pub_key_file(key):
-            try_path = key
-            if add_deploy_dir and state.cwd:
-                try_path = path.join(state.cwd, key)
-
-            if path.exists(try_path):
-                with open(try_path, "r") as f:
-                    return f.read()
-
-            return key
-
-        public_keys = list(map(read_any_pub_key_file, public_keys))
-
-        # Ensure .ssh directory
-        # note that this always outputs commands unless the SSH user has access to the
-        # authorized_keys file, ie the SSH user is the user defined in this function
-        yield from files.directory(
-            "{0}/.ssh".format(home),
-            user=user,
-            group=group or user,
-            mode=700,
+        yield from user_authorized_keys(
+            user,
+            public_keys,
+            group=group,
+            delete_keys=delete_keys,
+            authorized_key_directory="{0}/.ssh".format(home),
+            authorized_key_filename=None,
         )
-
-        filename = "{0}/.ssh/authorized_keys".format(home)
-
-        if delete_keys:
-            # Create a whole new authorized_keys file
-            keys_file = StringIO(
-                "{0}\n".format(
-                    "\n".join(public_keys),
-                ),
-            )
-
-            # And ensure it exists
-            yield from files.put(
-                src=keys_file,
-                dest=filename,
-                user=user,
-                group=group or user,
-                mode=600,
-            )
-
-        else:
-            # Ensure authorized_keys exists
-            yield from files.file(
-                path=filename,
-                user=user,
-                group=group or user,
-                mode=600,
-            )
-
-            # And every public key is present
-            for key in public_keys:
-                yield from files.line(path=filename, line=key)
