@@ -456,14 +456,10 @@ class TestSSHConnector(TestCase):
         assert out[0] is False
 
     @patch("pyinfra.connectors.util.getpass")
-    @patch("pyinfra.connectors.util.get_sudo_askpass_exe")
     @patch("pyinfra.connectors.ssh.SSHClient")
-    @patch("pyinfra.connectors.ssh.SFTPClient")
     def test_run_shell_command_sudo_password_prompt(
         self,
-        fake_sftp_client,
         fake_ssh_client,
-        fake_get_sudo_askpass_exe,
         fake_getpass,
     ):
         fake_ssh = MagicMock()
@@ -479,6 +475,7 @@ class TestSSHConnector(TestCase):
         host.connect()
 
         command = "echo Šablony"
+        fake_stdout.__iter__.return_value = ["/tmp/pyinfra-sudo-askpass-XXXXXXXXXXXX"]
         fake_stdout.channel.recv_exit_status.return_value = 0
 
         out = host.run_shell_command(command, sudo=True, use_sudo_password=True, print_output=True)
@@ -487,40 +484,34 @@ class TestSSHConnector(TestCase):
         status, stdout, stderr = out
         assert status is True
 
-        fake_sftp_client.from_transport().putfo.assert_called_with(
-            fake_get_sudo_askpass_exe.return_value,
-            "pyinfra-sudo-askpass",
-        )
-
         fake_ssh.exec_command.assert_called_with(
             (
-                "env SUDO_ASKPASS=pyinfra-sudo-askpass PYINFRA_SUDO_PASSWORD=password "
+                "env SUDO_ASKPASS=/tmp/pyinfra-sudo-askpass-XXXXXXXXXXXX "
+                "PYINFRA_SUDO_PASSWORD=password "
                 "sudo -H -A -k sh -c 'echo Šablony'"
             ),
             get_pty=False,
         )
 
     @patch("pyinfra.connectors.util.getpass")
-    @patch("pyinfra.connectors.util.get_sudo_askpass_exe")
     @patch("pyinfra.connectors.ssh.SSHClient")
-    @patch("pyinfra.connectors.ssh.SFTPClient")
     def test_run_shell_command_sudo_password_automatic_prompt(
         self,
-        fake_sftp_client,
         fake_ssh_client,
-        fake_get_sudo_askpass_exe,
         fake_getpass,
     ):
         fake_ssh = MagicMock()
         first_fake_stdout = MagicMock()
         second_fake_stdout = MagicMock()
+        third_fake_stdout = MagicMock()
 
         first_fake_stdout.__iter__.return_value = ["sudo: a password is required\r"]
+        second_fake_stdout.__iter__.return_value = ["/tmp/pyinfra-sudo-askpass-XXXXXXXXXXXX"]
 
         fake_ssh.exec_command.side_effect = [
             (MagicMock(), first_fake_stdout, MagicMock()),  # command w/o sudo password
-            (MagicMock(), MagicMock(), MagicMock()),  # command to chmod askpass file
-            (MagicMock(), second_fake_stdout, MagicMock()),  # command with sudo pw
+            (MagicMock(), second_fake_stdout, MagicMock()),  # SUDO_ASKPASS_COMMAND
+            (MagicMock(), third_fake_stdout, MagicMock()),  # command with sudo pw
         ]
 
         fake_ssh_client.return_value = fake_ssh
@@ -534,6 +525,7 @@ class TestSSHConnector(TestCase):
         command = "echo Šablony"
         first_fake_stdout.channel.recv_exit_status.return_value = 1
         second_fake_stdout.channel.recv_exit_status.return_value = 0
+        third_fake_stdout.channel.recv_exit_status.return_value = 0
 
         out = host.run_shell_command(command, sudo=True, print_output=True)
         assert len(out) == 3
@@ -541,16 +533,12 @@ class TestSSHConnector(TestCase):
         status, stdout, stderr = out
         assert status is True
 
-        fake_sftp_client.from_transport().putfo.assert_called_with(
-            fake_get_sudo_askpass_exe.return_value,
-            "pyinfra-sudo-askpass",
-        )
-
         fake_ssh.exec_command.assert_any_call(("sudo -H -n sh -c 'echo Šablony'"), get_pty=False)
 
         fake_ssh.exec_command.assert_called_with(
             (
-                "env SUDO_ASKPASS=pyinfra-sudo-askpass PYINFRA_SUDO_PASSWORD=password "
+                "env SUDO_ASKPASS=/tmp/pyinfra-sudo-askpass-XXXXXXXXXXXX "
+                "PYINFRA_SUDO_PASSWORD=password "
                 "sudo -H -A -k sh -c 'echo Šablony'"
             ),
             get_pty=False,
@@ -580,6 +568,7 @@ class TestSSHConnector(TestCase):
         state = State(inventory, Config())
         host = inventory.get_host("somehost")
         host.connect(state)
+        host.connector_data["sudo_askpass_path"] = "/tmp/pyinfra-sudo-askpass-XXXXXXXXXXXX"
 
         command = "echo hi"
         return_values = [1, 0]  # return 0 on the second call
@@ -590,7 +579,8 @@ class TestSSHConnector(TestCase):
         assert out[0] is True
         assert fake_get_sudo_password.called
         fake_ssh.exec_command.assert_called_with(
-            "env SUDO_ASKPASS=pyinfra-sudo-askpass PYINFRA_SUDO_PASSWORD=PASSWORD sh -c 'echo hi'",
+            "env SUDO_ASKPASS=/tmp/pyinfra-sudo-askpass-XXXXXXXXXXXX "
+            "PYINFRA_SUDO_PASSWORD=PASSWORD sh -c 'echo hi'",
             get_pty=False,
         )
 
